@@ -59,7 +59,7 @@ impl InMemoryCache {
         let id = (guild_id, user_id);
 
         if let Some(m) = self.members.get(&id) {
-            if *m == member {
+            if &*m == member {
                 return;
             }
         }
@@ -88,11 +88,12 @@ impl InMemoryCache {
         &self,
         guild_id: GuildId,
         member: &InteractionMember,
+        user_id: UserId,
     ) {
-        let id = (guild_id, member.id);
+        let id = (guild_id, user_id);
 
         let (avatar, deaf, mute) = match self.members.get(&id) {
-            Some(m) if *m == member => return,
+            Some(m) if &*m == member => return,
             Some(m) => (m.avatar().map(ToString::to_string), m.deaf(), m.mute()),
             None => (None, None, None),
         };
@@ -100,7 +101,7 @@ impl InMemoryCache {
         self.guild_members
             .entry(guild_id)
             .or_default()
-            .insert(member.id);
+            .insert(user_id);
 
         let cached = CachedMember {
             avatar,
@@ -112,7 +113,7 @@ impl InMemoryCache {
             pending: false,
             premium_since: member.premium_since.to_owned(),
             roles: member.roles.to_owned(),
-            user_id: member.id,
+            user_id,
         };
 
         self.members.insert(id, cached);
