@@ -141,6 +141,7 @@ mod tests {
 
     #[test]
     fn test_message_create() {
+        let joined_at = Timestamp::from_secs(1_632_072_645).expect("non zero");
         let cache = InMemoryCache::builder()
             .resource_types(ResourceType::MESSAGE | ResourceType::MEMBER | ResourceType::USER)
             .message_cache_size(1)
@@ -178,8 +179,9 @@ mod tests {
             interaction: None,
             kind: MessageType::Regular,
             member: Some(PartialMember {
+                avatar: None,
                 deaf: false,
-                joined_at: None,
+                joined_at,
                 mute: false,
                 nick: Some("member nick".to_owned()),
                 permissions: None,
