@@ -13,6 +13,7 @@ use twilight_model::{
 };
 
 pub fn cache_with_message_and_reactions() -> InMemoryCache {
+    let joined_at = Timestamp::from_secs(1_632_072_645).expect("non zero");
     let cache = InMemoryCache::new();
 
     let msg = Message {
@@ -48,8 +49,9 @@ pub fn cache_with_message_and_reactions() -> InMemoryCache {
         interaction: None,
         kind: MessageType::Regular,
         member: Some(PartialMember {
+            avatar: None,
             deaf: false,
-            joined_at: None,
+            joined_at,
             mute: false,
             nick: Some("member nick".to_owned()),
             permissions: None,
@@ -81,9 +83,10 @@ pub fn cache_with_message_and_reactions() -> InMemoryCache {
         },
         guild_id: Some(GuildId::new(1).expect("non zero")),
         member: Some(Member {
+            avatar: None,
             deaf: false,
             guild_id: GuildId::new(1).expect("non zero"),
-            joined_at: None,
+            joined_at,
             mute: false,
             nick: Some("member nick".to_owned()),
             pending: false,
@@ -114,9 +117,10 @@ pub fn cache_with_message_and_reactions() -> InMemoryCache {
     cache.update(&reaction);
 
     reaction.member.replace(Member {
+        avatar: None,
         deaf: false,
         guild_id: GuildId::new(1).expect("non zero"),
-        joined_at: None,
+        joined_at,
         mute: false,
         nick: None,
         pending: false,
@@ -207,10 +211,13 @@ pub fn guild_channel_text() -> (GuildId, ChannelId, GuildChannel) {
 }
 
 pub fn member(id: UserId, guild_id: GuildId) -> Member {
+    let joined_at = Timestamp::from_secs(1_632_072_645).expect("non zero");
+
     Member {
+        avatar: None,
         deaf: false,
         guild_id,
-        joined_at: None,
+        joined_at,
         mute: false,
         nick: None,
         pending: false,
